import {Component, inject} from '@angular/core';
import {
  MAT_DIALOG_DATA,
  MatDialog,
  MatDialogActions,
  MatDialogContent,
  MatDialogRef,
  MatDialogTitle
} from "@angular/material/dialog";
import QualificationService from "../../services/qualification.service";
import {Qualification} from "../Qualification";
import {AsyncPipe} from "@angular/common";
import {MatButton} from "@angular/material/button";
import {DetailsComponent as EmployeeDetailsComponent} from "../../employee/details/details.component";
import EmployeeApiService from "../../services/employee-api.service";
import {MatIcon} from "@angular/material/icon";

@Component({
  selector: 'app-details',
  imports: [
    AsyncPipe,
    MatDialogContent,
    MatDialogTitle,
    MatDialogActions,
    MatButton,
    MatIcon
  ],
  templateUrl: './details.component.html',
  styleUrl: './details.component.css'
})
export class DetailsComponent {
  private qualificationService = inject(QualificationService);
  private employeeService = inject(EmployeeApiService);
  private dialogRef: MatDialogRef<DetailsComponent> = inject(MatDialogRef);
  private dialog: MatDialog = inject(MatDialog);

  public qualification: Qualification = inject(MAT_DIALOG_DATA);
  public employees$ = this.qualificationService.findEmployees(this.qualification.id);

  closeModal() {
    this.dialogRef.close();
  }

  openEmployeeDetailsModal(id: number | undefined) {
    if (!id) {
      throw new Error("ID must not be undefined");
    }

    this.employeeService.getById(id).subscribe(employee => {
      this.dialog.open(EmployeeDetailsComponent, {
        data: employee
      });
    });
  }
}
