import {inject, Injectable} from "@angular/core";
import {HttpClient} from "@angular/common/http";
import {Observable} from "rxjs";
import {Employee} from "../employee/Employee";


@Injectable({
  providedIn: 'root'
})
export default class EmployeeApiService {
  private http: HttpClient = inject(HttpClient);

  private static readonly BASE_URL = 'http://localhost:8089';

  public getById(id: number): Observable<Employee> {
    return this.http.get(`${EmployeeApiService.BASE_URL}/employees/${id}`)
  }

  public deleteById(id: number): Observable<Employee> {
    return this.http.delete(`${EmployeeApiService.BASE_URL}/employees/${id}`)
  }

  public getAll(): Observable<Employee[]> {
    return this.http.get<Employee[]>(`${EmployeeApiService.BASE_URL}/employees`)
  }

  public create(employee: Employee) {
    return this.http.post<Employee>(`${EmployeeApiService.BASE_URL}/employees`, employee)
  }

  public update(employee: Employee, id: number) {
    return this.http.put(`${EmployeeApiService.BASE_URL}/employees/${id}`, employee)
  }
}
